@@ -40,6 +40,7 @@ class QAction;
  **/
 class AppMenuWidget : public KXmlGuiWindow
 {
+    Q_OBJECT
 public:
     /** constructor */
     AppMenuWidget();
@@ -60,10 +61,6 @@ private:
     QLabel * labelLearning;
     QLabel * labelInfo;
 
-    QAction * m_NewTaskAction;
-    QAction * m_BackAction;
-    QAction * m_HintAction;
-
     MainQtWidget * kbruchApp;
     FractionRingWidget * fractionRing;
 
